@@ -1,4 +1,4 @@
-/* cred.c	Implementation of GSS-API Credential Management functions.
+/* cred.c --- Implementation of GSS-API Credential Management functions.
  * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* _gss_find_mech */
+#include "meta.h"
+
 /**
  * gss_acquire_cred:
  * @minor_status: (integer, modify) Mechanism specific status code.
@@ -368,56 +371,32 @@ gss_inquire_cred (OM_uint32 * minor_status,
 		  OM_uint32 * lifetime,
 		  gss_cred_usage_t * cred_usage, gss_OID_set * mechanisms)
 {
+  gss_cred_id_t credh = cred_handle;
   _gss_mech_api_t mech;
-  gss_cred_id_t local_cred_handle = GSS_C_NO_CREDENTIAL;
   OM_uint32 maj_stat;
 
   if (cred_handle == GSS_C_NO_CREDENTIAL)
     {
-      gss_OID_set mechs;
-
-      maj_stat = gss_acquire_cred (minor_status,
-				   GSS_C_NO_NAME,
-				   GSS_C_INDEFINITE,
-				   GSS_C_NO_OID_SET,
-				   GSS_C_INITIATE,
-				   &local_cred_handle, &mechs, NULL);
+      maj_stat = gss_acquire_cred (minor_status, GSS_C_NO_NAME,
+				   GSS_C_INDEFINITE, GSS_C_NO_OID_SET,
+				   GSS_C_INITIATE, &credh, NULL, NULL);
       if (GSS_ERROR (maj_stat))
 	return maj_stat;
-
-      /* We assume all mechanisms the credential claim to support can
-         handle the inquire_cred call. */
-      mech = _gss_find_mech (mechs->elements);
-
-      gss_release_oid_set (NULL, &mechs);
-
-      if (mech == NULL)
-	{
-	  if (minor_status)
-	    *minor_status = 0;
-	  return GSS_S_BAD_MECH;
-	}
     }
-  else
+
+  mech = _gss_find_mech (credh->mech);
+  if (mech == NULL)
     {
-      mech = _gss_find_mech (cred_handle->mech);
-
-      if (mech == NULL)
-	{
-	  gss_warn ("gss_inquire_cred bug, report to %s", PACKAGE_BUGREPORT);
-	  if (minor_status)
-	    *minor_status = 0;
-	  return GSS_S_DEFECTIVE_CREDENTIAL;
-	}
+      if (minor_status)
+	*minor_status = 0;
+      return GSS_S_BAD_MECH;
     }
 
-  maj_stat = mech->inquire_cred (minor_status,
-				 local_cred_handle != GSS_C_NO_CREDENTIAL ?
-				 local_cred_handle : cred_handle,
-				 name, lifetime, cred_usage, mechanisms);
+  maj_stat = mech->inquire_cred (minor_status, credh, name, lifetime,
+				 cred_usage, mechanisms);
 
-  if (local_cred_handle != GSS_C_NO_CREDENTIAL)
-    gss_release_cred (NULL, &local_cred_handle);
+  if (cred_handle == GSS_C_NO_CREDENTIAL)
+    gss_release_cred (NULL, &credh);
 
   return maj_stat;
 }
@@ -479,7 +458,7 @@ gss_inquire_cred_by_mech (OM_uint32 * minor_status,
 			  gss_cred_usage_t * cred_usage)
 {
   _gss_mech_api_t mech;
-  gss_cred_id_t local_cred_handle = GSS_C_NO_CREDENTIAL;
+  gss_cred_id_t credh = cred_handle;
   OM_uint32 maj_stat;
 
   if (mech_type == GSS_C_NO_OID)
@@ -506,23 +485,18 @@ gss_inquire_cred_by_mech (OM_uint32 * minor_status,
 				      as desired_mechs.  Maybe even
 				      check actual_mechs too. */
 				   GSS_C_NO_OID_SET,
-				   GSS_C_INITIATE,
-				   &local_cred_handle, NULL, NULL);
+				   GSS_C_INITIATE, &credh, NULL, NULL);
       if (GSS_ERROR (maj_stat))
 	return maj_stat;
     }
 
-  maj_stat = mech->inquire_cred_by_mech
-    (minor_status,
-     local_cred_handle != GSS_C_NO_CREDENTIAL ?
-     local_cred_handle : cred_handle,
-     mech_type, name, initiator_lifetime, acceptor_lifetime, cred_usage);
+  maj_stat = mech->inquire_cred_by_mech (minor_status, credh, mech_type, name,
+					 initiator_lifetime,
+					 acceptor_lifetime, cred_usage);
 
-  if (local_cred_handle != GSS_C_NO_CREDENTIAL)
-    gss_release_cred (NULL, &local_cred_handle);
+  if (cred_handle == GSS_C_NO_CREDENTIAL)
+    gss_release_cred (NULL, &credh);
 
-  if (minor_status)
-    *minor_status = 0;
   return maj_stat;
 }
 
@@ -568,7 +542,6 @@ gss_release_cred (OM_uint32 * minor_status, gss_cred_id_t * cred_handle)
   mech = _gss_find_mech ((*cred_handle)->mech);
   if (mech == NULL)
     {
-      gss_warn ("gss_release_cred bug, report to %s", PACKAGE_BUGREPORT);
       if (minor_status)
 	*minor_status = 0;
       return GSS_S_DEFECTIVE_CREDENTIAL;
